@@ -1,9 +1,11 @@
+from rich.text import Text
+
 from textual.app import App, ComposeResult
 from textual.widgets import RadioButton, RadioSet
 
 
 class RadioChoicesApp(App[None]):
-    CSS_PATH = "radio_button.css"
+    CSS_PATH = "radio_button.tcss"
 
     def compose(self) -> ComposeResult:
         with RadioSet():
@@ -15,7 +17,9 @@ class RadioChoicesApp(App[None]):
             yield RadioButton("Star Wars: A New Hope")
             yield RadioButton("The Last Starfighter")
             yield RadioButton(
-                "Total Recall :backhand_index_pointing_right: :red_circle:"
+                Text.from_markup(
+                    "Total Recall :backhand_index_pointing_right: :red_circle:"
+                )
             )
             yield RadioButton("Wing Commander")
 
