@@ -13,7 +13,7 @@ def goodbye(name):
 
 class TextAreaSelection(App):
     def compose(self) -> ComposeResult:
-        text_area = TextArea(TEXT, language="python")
+        text_area = TextArea.code_editor(TEXT, language="python")
         text_area.selection = Selection(start=(0, 0), end=(2, 0))  # (1)!
         yield text_area
 
